@@ -31,6 +31,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../buffer.h"
 #include "../modules.h"
 #include "../ip_buffer_entry.h"
+#include "../ip_buffer_entry_struct.h"
 #include "../message_addr.h"
 #include "../message_log.h"
 #include "../messages.h"
@@ -422,7 +423,7 @@ static int __rrr_cmodule_helper_read_from_forks (
 		}
 
 		if (node->pid == 0) {
-			RRR_MSG_0("A worker fork '%s' had exited while attempting to read in rrr_cmodule_read_from_forks\n",
+			RRR_MSG_0("A worker fork '%s' had exited while attempting to read in __rrr_cmodule_helper_read_from_forks \n",
 					node->name);
 			ret = 1;
 			goto out;
@@ -691,7 +692,8 @@ void rrr_cmodule_helper_loop (
 
 	if (rrr_poll_collection_count(poll) == 0) {
 		if (INSTANCE_D_CMODULE(thread_data)->config_data.do_processing != 0) {
-			RRR_MSG_0("Instance %s had no senders but a processor function is defined, this is an invalid configuration.\n");
+			RRR_MSG_0("Instance %s had no senders but a processor function is defined, this is an invalid configuration.\n",
+				INSTANCE_D_NAME(thread_data));
 			return;
 		}
 		no_polling = 1;
@@ -718,6 +720,11 @@ void rrr_cmodule_helper_loop (
 	while (rrr_thread_check_encourage_stop(thread_data->thread) != 1 && fork_pid != 0) {
 		rrr_thread_update_watchdog_time(thread_data->thread);
 
+		if (rrr_thread_check_any_stopped(reader_thread_data.thread_collection)) {
+			RRR_MSG_0("Read thread stopped in cmodule instance %s\n", INSTANCE_D_NAME(thread_data));
+			break;
+		}
+
 		int from_senders_count_tmp = 0;
 
 //		printf ("From fork: %i\n", from_child_count_tmp);
