@@ -38,6 +38,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../lib/buffer.h"
 #include "../lib/ip.h"
 #include "../lib/ip_buffer_entry.h"
+#include "../lib/ip_buffer_entry_struct.h"
+#include "../lib/ip_buffer_entry_collection.h"
 #include "../lib/instances.h"
 #include "../lib/instance_config.h"
 #include "../lib/settings.h"
